# -*- coding: utf-8 -*-
"""
    xmlrunner.version
    ~~~~~~~~~~~~~~~~~

    Runtime library version information.

    :codeauthor: :email:`PyContribs (pycontribs@googlegroups.com)`
    :copyright: © 2013 Pedro Algarvio.
    :copyright: © 2014 Sorin Sbarnea.

    :license: LGPL, see LICENSE for more details.
"""

__version_info__ = (1, 7, 5)
__version__ = '.'.join(map(str, __version_info__))
